@@ -46,6 +46,7 @@ loon_reactive.l_hist <- function(loon.grob, output.grob, linkingInfo, buttons, p
       brushId <- outputInfo$brushId
       selectByColor <- outputInfo$selectByColor
     }
+
   } else {
 
     output.grob <- loon.grob
@@ -395,10 +396,17 @@ loon_reactive.l_hist <- function(loon.grob, output.grob, linkingInfo, buttons, p
 
     # reset boundary
     output.grob <- set_boundaryGrob(loon.grob = output.grob,
-                                     margins = margins,
-                                     loonColor = loonColor)
+                                    margins = margins,
+                                    loonColor = loonColor)
 
     # +++++++++++++++++++++++++++++++++++++++++ set other aesthetic ++++++++++++++++++++++++++++++++++++++++
+    vp <- grid::vpStack(
+      grid::plotViewport(margins = margins, name = "plotViewport"),
+      grid::dataViewport(xscale = xlim,
+                         yscale = ylim,
+                         name = "dataViewport")
+    )
+
     brushId <- if(initialDisplay) {
 
       outputInfo$brushId
@@ -411,23 +419,26 @@ loon_reactive.l_hist <- function(loon.grob, output.grob, linkingInfo, buttons, p
 
       } else {
 
-        get_brushId(
-          loon.grob = output.grob,
-          coord = binxy,
-          swapInShiny = swapInShiny,
-          position = position,
-          brushInfo = plotBrush,
-          vp = grid::vpStack(
-            grid::plotViewport(margins = margins, name = "grid::plotViewport"),
-            grid::dataViewport(xscale = xlim,
-                               yscale = ylim,
-                               name = "dataViewport")
-          ),
-          clickInfo = plotClick
-        )
+        if(!is.null(position))
+          get_brushId(
+            loon.grob = output.grob,
+            coord = binxy,
+            swapInShiny = swapInShiny,
+            position = position,
+            brushInfo = plotBrush,
+            vp = vp,
+            clickInfo = plotClick
+          )
       }
     }
 
+    # query the `offset`
+    loonWidgetsInfo$offset <- get_offset(vp = vp,
+                                         l = plotBrush$domain$left %||% plotClick$domain$left %||% -0.04,
+                                         r = plotBrush$domain$right %||% plotClick$domain$right %||% 1.04,
+                                         b = plotBrush$domain$bottom %||% plotClick$domain$bottom %||% -0.04,
+                                         t = plotBrush$domain$top %||% plotClick$domain$top %||% 1.04)
+
     # dynamic select -----------------------------------------------
     selectDynamic <- input[[paste0(tabPanelName, "selectDynamic")]]
     sticky <- input[[paste0(tabPanelName, "sticky")]]
